#!/usr/bin/env python

# livecd-pkgs-get - Provides a list of packages included in the LiveCD of a
# given distro
#
# Author: David Planella <david.planella@ubuntu.com> and
#   Kyle Nitzsche <kyle.nitzsche@canonical.com>
#
# Copyright (c) 2009, 2010 Canonical Ltd.
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

import urllib2
import csv
import gzip
from common.utils import init_logging

logger = init_logging("ul10nIsoPotsGet")

class DistroSeeds(object):
    """A class that can be used to obtain all source packages resulting from
    expanding the seeds for a given distro.

    These will represent all source packages for all binaries on a default
    installation of the distro.
    """
    DESKTOP_SEEDS = ('boot', 'required', 'minimal', 'standard',
                     'desktop-common', 'desktop')

    SEEDS_CANONICAL_URL = \
        'http://people.canonical.com/~ubuntu-archive/germinate-output'

    def __init__(self, distro_id, distro_codename):
        """Initialize the distro attributes and compile the URL for the
        seeds.
        """
        self.distro_id = distro_id
        self.distro_codename = distro_codename
        self.seeds_distro_url = '{0}/{1}.{2}'.format(self.SEEDS_CANONICAL_URL,
                                                     distro_id,
                                                     distro_codename)
        self.sourcepackages = set()

    def get_sourcepackages(self):
        """Fetch all seeds, combine them, extract the source packages and
        store them as a list in an internal attribute
        """
        for seed in self.DESKTOP_SEEDS:
            seed_url = '{0}/{1}'.format(self.seeds_distro_url, seed)
            seed_opener = urllib2.build_opener()
            try:
                seed_file = seed_opener.open(seed_url)
                seed = seed_file.read()
            except urllib2.URLError, exc:
                logger.critical(
                    "Error opening {0}: {1}\n\
                    Cannot continue.".format(seed_url, exc))
                sys.exit(1)
            else:
                seed_reader = csv.reader(seed.splitlines(), delimiter='|')
                for row in seed_reader:
                    first_row = row[0].strip()
                    if (first_row != 'Package') and not (
                            first_row.startswith('-') or first_row == ''):
                        self.sourcepackages.add(row[1].strip())

    def _get_sourcepackages_len(self):
        """Return the number of source packages of the given distro's
        default installation.
        """
        return len(self.sourcepackages)
