#!/usr/bin/env python

# utils - Provides several helper functions
#
# Author: Kyle Nitzsche <kyle.nitzsche@canonical.com>
#
# Copyright (c) 20100 Canonical Ltd.
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

import sys
import os
import logging
import gzip
from utils import init_logging
import logging.config


class LpSrcPkgs():
    """A class to represent and provide access to Source Packages' LP 
translations"""

    def __init__(self, _file):
        self.srcpkgs = self._get_srcpkgs_from_file(_file)
        #self.template_src = self._make_template_src_dict(self.templates_enabled)
        return

    def _get_srcpkgs_from_file(self, _f):
        """Returns list of dictionaries for all LP src pkgs"""

        logger = init_logging("ul10nSrcPkgs")
        if not os.path.exists(_f):
            logger.error("Path to templates file does not exist. Stopping")
            sys.exit(1)
        lines = gzip.open(_f, 'rb').readlines()
        start = 0
        srcpkgs = []
        for line in lines:
            if start < 2:
                start += 1
                continue
            if line.startswith("("): break

            srcpkg_dict = dict()
            items = line.split("|")
            srcpkg_dict['src'] = items[0].strip()
            srcpkg_dict['domain'] = items[1].strip()
            srcpkg_dict['template'] = items[2].strip()
            srcpkg_dict['template_update_date'] = items[3].strip()
            srcpkg_dict['translation_update_date'] = items[4].strip()
            srcpkg_dict['language'] = items[5].strip()
            srcpkg_dict['translated'] = items[6].strip()
            srcpkg_dict['unreviewed'] = items[7].strip()
            srcpkg_dict['changed'] = items[8].strip()
            srcpkg_dict['total'] = items[9].strip()
            srcpkgs.append(srcpkg_dict)
        #print str(srcpkgs)
        return srcpkgs

    def _make_domain_src_dict(self, srcpkgs):
        domain_src = dict()
        for record in srcpkgs:
            domaine_src[record['domain']] = record['src']
        return template_src

